@@ -1,37 +1,26 @@
 from __future__ import annotations
-from abc import ABC, abstractmethod
 
 import itertools
 import logging
 import random
-from typing import (
-    Any,
-    Callable,
-    Deque,
-    Dict,
-    FrozenSet,
-    Generic,
-    Iterable,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Tuple,
-    TypeVar,
-)
-from typing_extensions import Self, TypeVar
+from abc import ABC, abstractmethod
+from typing import Any, Callable, Generic, Mapping, Optional, Sequence, TypeVar, Union
 from uuid import uuid4
 
 import numpy as np  # type: ignore
-import pandas as pd  # type: ignore
+from typing_extensions import Self, TypeVar
 
-from ..environment import AbstractEnvironment
+from ..activelearning.autostop import AutoStopLearner
+from ..activelearning.autotar import PSEUDO_INS_PROVIDER
+
+from ..activelearning.learnersequence import LearnerSequence  # type: ignore
+from ..activelearning.autotarensemble import AutoTARFirstMethod
 from ..activelearning.base import ActiveLearner
 from ..activelearning.estimator import Estimator
 from ..activelearning.target import TargetMethod
-from ..activelearning.autotarensemble import AutoTARFirstMethod
-
-from ..typehints import KT, LT, IT, DT, VT, RT
+from ..activelearning.cmh import CMHMethod
+from ..typehints import DT, IT, KT, LT, RT, VT
+from instancelib.ingest.qrel import TrecDataset
 
 LOGGER = logging.getLogger(__name__)
 
@@ -53,6 +42,29 @@ class Initializer(ABC, Generic[IT, KT, LT]):
         return builder_func
 
 
+class PseudoInstanceInitializer(Initializer[IT, KT, LT], Generic[IT, KT, DT, LT]):
+    def __init__(self, pseudo_data: DT, pseudo_label: LT):
+        self.pseudo_data = pseudo_data
+        self.pseudo_label = pseudo_label
+        self.pseudo_id = uuid4()
+
+    def __call__(
+        self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
+    ) -> ActiveLearner[IT, KT, DT, VT, RT, LT]:
+        ins = learner.env.create(data=self.pseudo_data, vector=None)
+        learner.env.create_named_provider(PSEUDO_INS_PROVIDER, [ins.identifier])
+        return learner
+
+    @classmethod
+    def from_trec(
+        cls, trec: TrecDataset, topic_id: str
+    ) -> PseudoInstanceInitializer[IT, str, str, str]:
+        topic_df = trec.topics.set_index("id")
+        topic_row = topic_df.xs(topic_id)
+        pseudo_data: str = topic_row.title + " " + topic_row.query  # type: ignore
+        return cls(pseudo_data, trec.pos_label)  # type: ignore
+
+
 class IdentityInitializer(Initializer[IT, KT, LT], Generic[IT, KT, LT]):
     def __call__(
         self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
@@ -79,7 +91,7 @@ class RandomInitializer(Initializer[IT, KT, LT], Generic[IT, KT, LT]):
             itertools.chain.from_iterable(
                 map(
                     lambda lbl: self.get_random_sample_for_label(learner, lbl),
-                    sorted(learner.env.labels.labelset),
+                    sorted(list(learner.env.labels.labelset)),
                 )
             )
         )
@@ -112,12 +124,12 @@ class RandomInitializer(Initializer[IT, KT, LT], Generic[IT, KT, LT]):
 
 class SeededRandomInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]):
     rng: np.random.Generator
-    seed: None | int | np.random.BitGenerator | np.random.Generator
+    seed: Optional[Union[int, np.random.BitGenerator, np.random.Generator]]
 
     def __init__(
         self,
         sample_size: int = 1,
-        seed: None | int | np.random.BitGenerator | np.random.Generator = 42,
+        seed: Optional[Union[int, np.random.BitGenerator, np.random.Generator]] = None,
     ) -> None:
         super().__init__(sample_size)
         self.seed = seed
@@ -133,9 +145,18 @@ class SeededRandomInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]
 
     @classmethod
     def builder(
-        cls, sample_size: int, seed: int, *args, **kwargs
+        cls,
+        sample_size: int,
+        *args,
+        **kwargs,
     ) -> Callable[..., Self]:
-        def builder_func(*args, **kwargs) -> Self:
+        def builder_func(
+            *args,
+            seed: Optional[
+                Union[int, np.random.BitGenerator, np.random.Generator]
+            ] = None,
+            **kwargs,
+        ) -> Self:
             return cls(sample_size, seed)
 
         return builder_func
@@ -180,6 +201,26 @@ class SeededEnsembleInitializer(
         return learner
 
 
+class AutoStopLargeInitializer(
+    SeededRandomInitializer[IT, KT, LT], Generic[IT, KT, LT]
+):
+    def __call__(
+        self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
+    ) -> ActiveLearner[IT, KT, DT, VT, RT, LT]:
+        if not isinstance(learner, LearnerSequence):
+            return super().__call__(learner)
+        docs = self.get_initialization_sample(learner)
+        for sublearner in learner.learners:
+            if isinstance(sublearner, AutoStopLearner):
+                for doc in docs:
+                    if doc not in sublearner.env.dataset:
+                        sublearner.env.dataset.add(sublearner.env.all_instances[doc])
+                    self.add_doc(sublearner, doc)
+                    self.add_doc(learner, doc)
+                sublearner.key_seq = tuple(sublearner.env.dataset)
+        return learner
+
+
 class TargetInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]):
     def __call__(
         self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
@@ -194,6 +235,20 @@ class TargetInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]):
         return learner
 
 
+class CMHInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]):
+    def __call__(
+        self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
+    ) -> ActiveLearner[IT, KT, DT, VT, RT, LT]:
+        if not isinstance(learner, CMHMethod):
+            return super().__call__(learner)
+        sublearner = learner.learners[0]
+        docs = self.get_initialization_sample(learner)
+        for doc in docs:
+            self.add_doc(sublearner, doc)
+            self.add_doc(learner, doc)
+        return learner
+
+
 class PriorInitializer(RandomInitializer[IT, KT, LT], Generic[IT, KT, LT]):
     def __call__(
         self, learner: ActiveLearner[IT, KT, DT, VT, RT, LT]
